@@ -1,5 +1,5 @@
 #from .__main__ import main
-from mainGame
+import mainGame
 #from setuptools import setup, find_packages
 
 #setup(
